@@ -18,6 +18,10 @@
 #include "Stacktrace.h"
 #include "filesystem.h"
 
+#ifdef __APPLE__
+#include "osx/setup-env.h"
+#endif
+
 #ifdef _WIN32
 #include "win32/console.h"
 #endif
@@ -40,6 +44,11 @@ auto main(int argc, char* argv[]) -> int {
     _putenv_s("PANGOCAIRO_BACKEND", "fc");
 #endif
 
+#ifdef __APPLE__
+    // Setup the environment variables, in particular so that the pixbuf loaders are found
+    setupEnvironment();
+#endif
+
     // Use this two line to test the crash handler...
     // int* crash = nullptr;
     // *crash = 0;
