@@ -15,15 +15,16 @@
 #include <string>
 #include <vector>
 
+#include <glib.h>
+
 #include "model/PageType.h"
 
-#include "XournalType.h"
 #include "filesystem.h"
 
 class PageTypeInfo {
 public:
     PageType page;
-    string name;
+    std::string name;
 };
 
 class GladeSearchpath;
@@ -34,15 +35,15 @@ public:
     virtual ~PageTypeHandler();
 
 public:
-    vector<PageTypeInfo*>& getPageTypes();
-    static PageTypeFormat getPageTypeFormatForString(const string& format);
-    static string getStringForPageTypeFormat(const PageTypeFormat& format);
+    std::vector<PageTypeInfo*>& getPageTypes();
+    static PageTypeFormat getPageTypeFormatForString(const std::string& format);
+    static std::string getStringForPageTypeFormat(const PageTypeFormat& format);
 
 private:
-    void addPageTypeInfo(string name, PageTypeFormat format, string config);
+    void addPageTypeInfo(std::string name, PageTypeFormat format, std::string config);
     bool parseIni(fs::path const& filepath);
     void loadFormat(GKeyFile* config, const char* group);
 
 private:
-    vector<PageTypeInfo*> types;
+    std::vector<PageTypeInfo*> types;
 };
