@@ -3,7 +3,6 @@
 #include "control/settings/Settings.h"
 #include "gtk/gtk.h"
 #include "gui/inputdevices/touchdisable/TouchDisableCustom.h"
-#include "gui/inputdevices/touchdisable/TouchDisableGdk.h"
 #include "gui/inputdevices/touchdisable/TouchDisableX11.h"
 
 #include "InputContext.h"
@@ -24,8 +23,8 @@ HandRecognition::HandRecognition(GtkWidget* widget, InputContext* inputContext,
 
 HandRecognition::~HandRecognition() {
     // Enable touchscreen on quit application
-    if (!touchState) {
-        enableTouch();
+    if (!touchState && enabled && touchImpl) {
+        touchImpl->enableTouch();
     }
 
     delete touchImpl;
@@ -76,7 +75,6 @@ void HandRecognition::reload() {
         touchImpl = new TouchDisableCustom(enableCommand, disableCommand);
     } else  // Auto detect
     {
-        // touchImpl = new TouchDisableGdk(this->widget);
 #ifdef X11_ENABLED
         if (x11Session) {
             touchImpl = new TouchDisableX11();
@@ -139,7 +137,7 @@ void HandRecognition::penEvent() {
  */
 void HandRecognition::enableTouch() {
     if (inputContext) {
-        inputContext->unblockDevice(InputContext::TOUCHSCREEN);
+        inputContext->unblockDevice(InputContext::DeviceType::TOUCHSCREEN);
     }
     if (touchImpl && enabled) {
         touchImpl->enableTouch();
@@ -151,28 +149,20 @@ void HandRecognition::enableTouch() {
  */
 void HandRecognition::disableTouch() {
     if (inputContext) {
-        inputContext->blockDevice(InputContext::TOUCHSCREEN);
+        inputContext->blockDevice(InputContext::DeviceType::TOUCHSCREEN);
     }
     if (touchImpl) {
         touchImpl->disableTouch();
     }
 }
 
-/**
- * An event from a device occurred
- */
-void HandRecognition::event(GdkDevice* device) {
-    GdkInputSource dev = gdk_device_get_source(device);
-
-    if (dev == GDK_SOURCE_PEN || dev == GDK_SOURCE_ERASER) {
-        penEvent();
-    }
-}
-
 /**
  * An event from a device occurred
  */
 void HandRecognition::event(InputDeviceClass device) {
+    if (!enabled) {
+        return;
+    }
     if (device == INPUT_DEVICE_PEN || device == INPUT_DEVICE_ERASER) {
         penEvent();
     }
