@@ -19,7 +19,6 @@
 #include "gui/sidebar/previews/base/SidebarPreviewBase.h"
 #include "util/IconNameHelper.h"
 
-#include "XournalType.h"
 
 class SidebarPreviewPages: public SidebarPreviewBase {
 public:
@@ -37,12 +36,12 @@ public:
     /**
      * @overwrite
      */
-    virtual string getName();
+    virtual std::string getName();
 
     /**
      * @overwrite
      */
-    virtual string getIconName();
+    virtual std::string getIconName();
 
     /**
      * Update the preview images
