@@ -6,18 +6,18 @@ AudioElement::AudioElement(ElementType type): Element(type) {}
 
 AudioElement::~AudioElement() { this->timestamp = 0; }
 
-void AudioElement::setAudioFilename(string fn) { this->audioFilename = std::move(fn); }
+void AudioElement::setAudioFilename(std::string fn) { this->audioFilename = std::move(fn); }
 
-auto AudioElement::getAudioFilename() const -> string { return this->audioFilename; }
+auto AudioElement::getAudioFilename() const -> std::string { return this->audioFilename; }
 
 void AudioElement::setTimestamp(size_t timestamp) { this->timestamp = timestamp; }
 
 auto AudioElement::getTimestamp() const -> size_t { return this->timestamp; }
 
-void AudioElement::serializeAudioElement(ObjectOutputStream& out) {
+void AudioElement::serialize(ObjectOutputStream& out) const {
     out.writeObject("AudioElement");
 
-    serializeElement(out);
+    this->Element::serialize(out);
 
     out.writeString(this->audioFilename);
     out.writeSizeT(this->timestamp);
@@ -25,10 +25,10 @@ void AudioElement::serializeAudioElement(ObjectOutputStream& out) {
     out.endObject();
 }
 
-void AudioElement::readSerializedAudioElement(ObjectInputStream& in) {
+void AudioElement::readSerialized(ObjectInputStream& in) {
     in.readObject("AudioElement");
 
-    readSerializedElement(in);
+    this->Element::readSerialized(in);
 
     this->audioFilename = in.readString();
     this->timestamp = in.readSizeT();
