@@ -69,9 +69,9 @@ auto TexImage::cairoReadFunction(TexImage* image, unsigned char* data, unsigned
  */
 auto TexImage::getBinaryData() const -> std::string const& { return this->binaryData; }
 
-void TexImage::setText(string text) { this->text = std::move(text); }
+void TexImage::setText(std::string text) { this->text = std::move(text); }
 
-auto TexImage::getText() -> string { return this->text; }
+auto TexImage::getText() -> std::string { return this->text; }
 
 auto TexImage::loadData(std::string&& bytes, GError** err) -> bool {
     this->freeImageAndPdf();
@@ -121,10 +121,10 @@ void TexImage::rotate(double x0, double y0, double th) {
     // Rotation for TexImages not yet implemented
 }
 
-void TexImage::serialize(ObjectOutputStream& out) {
+void TexImage::serialize(ObjectOutputStream& out) const {
     out.writeObject("TexImage");
 
-    serializeElement(out);
+    this->Element::serialize(out);
 
     out.writeDouble(this->width);
     out.writeDouble(this->height);
@@ -138,7 +138,7 @@ void TexImage::serialize(ObjectOutputStream& out) {
 void TexImage::readSerialized(ObjectInputStream& in) {
     in.readObject("TexImage");
 
-    readSerializedElement(in);
+    this->Element::readSerialized(in);
 
     this->width = in.readDouble();
     this->height = in.readDouble();
