@@ -16,7 +16,7 @@
 #include <vector>
 
 #include "UndoAction.h"
-#include "XournalType.h"
+
 
 class EmergencySaveRestore: public UndoAction {
 public:
@@ -27,7 +27,7 @@ public:
     virtual bool undo(Control* control);
     virtual bool redo(Control* control);
 
-    virtual string getText();
+    virtual std::string getText();
 
 private:
 };
