@@ -25,7 +25,7 @@ public:
     virtual bool undo(Control* control);
     virtual bool redo(Control* control);
 
-    virtual string getText();
+    virtual std::string getText();
 
 private:
     LayerController* layerController;
