@@ -315,8 +315,10 @@ auto Util::getDataPath() -> fs::path {
     p = p / ".." / "share" / PROJECT_PACKAGE;
     return p;
 #elif defined(__APPLE__)
-    fs::path p = Stacktrace::getExePath();
-    p = p / ".." / "Resources";
+    fs::path p = Stacktrace::getExePath().parent_path();
+    if (fs::exists(p / "Resources")) {
+        p = p / "Resources";
+    }
     return p;
 #else
     fs::path p = PACKAGE_DATA_DIR;
