@@ -30,6 +30,11 @@ pid_t getPid();
  */
 void systemWithMessage(const char* command);
 
+/**
+ * Check if currently running in a Flatpak sandbox
+ */
+bool isFlatpakInstallation();
+
 /**
  * Execute the callback in the UI Thread.
  *
